@@ -4,7 +4,7 @@ use Moo;
 
 with 'MooX::CalcTime::Role';
 
-our $VERSION = '0.0.6'; # VERSION
+our $VERSION = '0.0.8'; # VERSION
 # ABSTRACT: This is a instantial object of MooX::CalcTime::Role
 
 
@@ -22,7 +22,7 @@ MooX::CalcTime - This is a instantial object of MooX::CalcTime::Role
 
 =head1 VERSION
 
-version 0.0.6
+version 0.0.8
 
 =head1 SYNOPSIS
 
@@ -35,7 +35,7 @@ version 0.0.6
   $t->get_run_second;
 
   # return a string such as 'Running time: 3 days 2 minutes 1 hours 10 minutes 5 second';
-  $t->get_runtime_format;
+  $t->get_runtime;
 
   # print return value of C<get_runtime_format> function
   $t->print_runtime;
