@@ -3,7 +3,7 @@ use Modern::Perl;
 use Moo::Role;
 use DateTime;
 
-our $VERSION = '0.0.6'; # VERSION
+our $VERSION = '0.0.8'; # VERSION
 # ABSTRACT: calculate total time that a program run
 
 
@@ -36,7 +36,7 @@ sub get_runtime {
 
 
 sub print_runtime {
-  say $_[0]->get_runtime_format;
+  say $_[0]->get_runtime;
 }
 
 
@@ -54,7 +54,7 @@ MooX::CalcTime::Role - calculate total time that a program run
 
 =head1 VERSION
 
-version 0.0.6
+version 0.0.8
 
 =head1 SYNOPSIS
 
@@ -68,7 +68,7 @@ version 0.0.6
     $self->get_run_second;
 
     # return a string such as 'Running time: 3 days 2 minutes 1 hours 10 minutes 5 second';
-    $self->get_runtime_format; # return a variable: '3 days 2 hours 1 minute'
+    $self->get_runtime; # return a variable: '3 days 2 hours 1 minute'
 
     # print return value of 'get_runtime_format' function
     $self->print_runtime;
